==> dnet-modular-repositories-ui-3.0.5-20141203.095940-1-sources.jar: eu/dnetlib/web/resources/js/repos.js <==
var module = angular.module('reposUI', ['ngGrid', 'ngRoute', 'repoControllers']);

addCommonDirectives(module);

module.config([
	'$routeProvider',
	function($routeProvider) {
		$routeProvider
		.when('/browse',                           { templateUrl: '../resources/html/repoBrowse.html', controller: 'repoBrowseCtrl' })
		.when('/list/:param/:value',               { templateUrl: '../resources/html/repoList.html',   controller: 'repoListCtrl'   })
		.when('/api/:repoId/:ifaceId/:metawf/:wf', { templateUrl: './repos/repoApi.html',    controller: 'repoApiCtrl'    })
		.otherwise({ redirectTo: '/browse' });
	}
]);

module.directive('ngApiMdstoreInfo', function() {
	return {
		restrict: 'E',
		scope: {
			'label' : '@',
			'date'  : '=',
			'total' : '=',
			'id'    : '='
		},
		templateUrl: '../resources/html/ngApiMdstoreInfo.html'
	}
});

module.directive('ngApiObjectstoreInfo', function() {
    return {
        restrict: 'E',
        scope: {
            'label' : '@',
            'date'  : '=',
            'total' : '=',
            'id'    : '='
        },
        templateUrl: '../resources/html/ngApiObjectstoreInfo.html'
    }
});

module.directive('ngRepoCountryCell', function() {
	return {
		restrict: 'E',
		templateUrl: '../resources/html/ngRepoCountryCell.html'
	}
});

module.directive('ngReponameCell', function() {
	return {
		restrict: 'E',
		templateUrl: '../resources/html/ngRepoNameCell.html'
	}
});

module.directive('ngAggrDateCell', function() {
	return {
		restrict: 'E',
		templateUrl: '../resources/html/ngAggrDateCell.html'
	}
});

module.directive('ngAggrTotalCell', function() {
	return {
		restrict: 'E',
		templateUrl: '../resources/html/ngAggrTotalCell.html'
	}
});

==> dnet-modular-repositories-ui-4.0.18-20180202.114123-13-sources.jar: eu/dnetlib/web/resources/js/repos.js <==
var module = angular.module('reposUI', ['ngGrid', 'ngRoute', 'repoControllers']);

addCommonDirectives(module);

module.config([
	'$routeProvider',
	function($routeProvider) {
		$routeProvider
		.when('/browse',                           { templateUrl: '../resources/html/repoBrowse.html', controller: 'repoBrowseCtrl' })
		.when('/list/:param/:value',               { templateUrl: '../resources/html/repoList.html',   controller: 'repoListCtrl'   })
		.when('/api/:repoId/:ifaceId/:metawf/:wf', { templateUrl: './repos/repoApi.html',    controller: 'repoApiCtrl'    })
		.otherwise({ redirectTo: '/browse' });
	}
]);

module.directive('ngApiMdstoreInfo', function() {
	return {
		restrict: 'E',
		scope: {
			'label' : '@',
			'date'  : '=',
			'total' : '=',
			'id'    : '='
		},
		templateUrl: '../resources/html/ngApiMdstoreInfo.html'
	}
});

module.directive('ngApiObjectstoreInfo', function() {
    return {
        restrict: 'E',
        scope: {
            'label' : '@',
            'date'  : '=',
            'total' : '=',
            'id'    : '='
        },
        templateUrl: '../resources/html/ngApiObjectstoreInfo.html'
    }
});

module.directive('ngRepoCountryCell', function() {
	return {
		restrict: 'E',
		templateUrl: '../resources/html/ngRepoCountryCell.html'
	}
});

module.directive('ngReponameCell', function() {
	return {
		restrict: 'E',
		templateUrl: '../resources/html/ngRepoNameCell.html',
		link: function(scope, elem, attrs) {
			var n = scope.row.getProperty('id').lastIndexOf('::');
			scope.shortId = scope.row.getProperty('id').substring(n + 2);
		}
	}
});

module.directive('ngAggrDateCell', function() {
	return {
		restrict: 'E',
		templateUrl: '../resources/html/ngAggrDateCell.html'
	}
});

module.directive('ngAggrTotalCell', function() {
	return {
		restrict: 'E',
		templateUrl: '../resources/html/ngAggrTotalCell.html'
	}
});
